@@ -1,7 +1,7 @@
 package Pod::PseudoPod::HTML;
 use strict;
 use vars qw( $VERSION );
-$VERSION = '0.09';
+$VERSION = '0.11';
 use Carp ();
 use base qw( Pod::PseudoPod );
 
@@ -23,7 +23,7 @@ sub new {
   $new->nbsp_for_S(1);
   $new->add_css_tags(0);
   $new->add_body_tags(0);
-  $new->codes_in_data(1);
+  $new->codes_in_verbatim(1);
   $new->{'scratch'} = '';
   return $new;
 }
@@ -81,8 +81,25 @@ sub start_sidebar {
 
 sub end_sidebar { $_[0]{'scratch'} .= $_[0]->{'css_tags'} ?  '</div>' : '</blockquote>'; $_[0]->emit() }
 
-sub start_figure { $_[0]{'in_figure'} = 1 }
-sub end_figure { $_[0]{'in_figure'} = 0 }
+sub start_figure { 
+  my ($self, $flags)      = @_;
+  $self->{'in_figure'}    = 1;
+
+  $self->{'figure_title'} = $flags->{'title'} if $flags->{'title'};
+}
+
+sub end_figure { 
+  my ($self, $flags)   = @_;
+  $self->{'in_figure'} = 0;
+
+  if ($self->{'figure_title'})
+  {
+    $self->{'scratch'} .= "<p><em>" . $self->{'figure_title'} . "</em></p>";
+    delete $self->{'figure_title'};
+  }
+
+  $self->emit('nowrap');
+}
 
 # This handles =begin and =for blocks of all kinds.
 sub start_for { 
